@@ -13,6 +13,7 @@ from twisted.python import log
 from cyclone.web import RequestHandler, Application, URLSpec, HTTPError
 
 from ..collections.errors import CollectionObjectNotFound, CollectionUsageError
+from ..queue.pausingdeferredqueue import PausingQueueCloseMarker
 
 
 class RouteParseError(Exception):
@@ -240,6 +241,18 @@ class BaseHandler(RequestHandler):
         self.set_header('Content-Type', 'application/json; charset=utf-8')
         self.write(json.dumps(page))
 
+    @inlineCallbacks
+    def write_queue(self, q):
+        self.set_header('Content-Type', 'application/json; charset=utf-8')
+        while True:
+            obj = yield q.get()
+            if obj is None:
+                continue
+            if isinstance(obj, PausingQueueCloseMarker):
+                break
+            self.write(json.dumps(obj))
+            self.write("\n")
+
     def parse_json(self, data):
         try:
             return json.loads(data)
@@ -271,7 +284,7 @@ class CollectionHandler(BaseHandler):
         stream = self.get_argument('stream', default='false')
         if stream == 'true':
             d = maybeDeferred(self.collection.stream, query=query)
-            d.addCallback(self.write_objects)
+            d.addCallback(self.write_queue)
         else:
             cursor = self.get_argument('cursor', default=None)
             max_results = self.get_argument('max_results', default=None)
